@@ -529,7 +529,7 @@ Rule.addVariable <- function(rule, dataset){
   #' @param tamTournament The size of the tornament (>= 2)
   #' 
   #' @return the index in \code{'pop'} of the best individual in the tournament.
-  #' 
+  #' @noRd
   tournamentSelection <- function(pop, tamTournament){
     if(tamTournament < 2)
       stop("'tamTournament' must be 2 or greater than 2.")
@@ -637,7 +637,7 @@ Rule.addVariable <- function(rule, dataset){
   #' @param ALL_CLASS if TRUE, the algorithm returns, at least, the best rule for each target class, even if it does not pass the filters. If FALSE, it only returns, at least, the best rule if there are not rules that passes the filters.
   #' @param targetVariable The name or index position of the target variable (or class). It must be a categorical one.
   #' 
-  #'  @details This function sets as target variable the last one that appear in \code{SDEFSR_Dataset} object. If you want 
+  #'@details This function sets as target variable the last one that appear in \code{SDEFSR_Dataset} object. If you want 
   #'     to change the target variable, you can set the \code{targetVariable} to change this target variable.
   #'     The target variable MUST be categorical, if it is not, throws an error. Also, the default behaviour is to find
   #'     rules for all possible values of the target varaible. \code{targetClass} sets a value of the target variable where the
@@ -671,9 +671,9 @@ Rule.addVariable <- function(rule, dataset){
   #'  
   #'  The algorithm evolves generating an offspring population of the same size than initial generated by the application of the
   #'  genetic operators over the main population. Once applied, both populations are joined a token competition is performed in order to 
-  #'  mantain the diversity of the rules generated. Also, this token competition reduce the population sice deleting those rules that are not competitive.  
+  #'  maintain the diversity of the rules generated. Also, this token competition reduce the population sice deleting those rules that are not competitive.  
   #'  
-  #'  After the evolutionary process a screening function is applied over the best population. This screening function filter the rules that have a minimium
+  #'  After the evolutionary process a screening function is applied over the best population. This screening function filter the rules that have a minimum
   #'  level of confidence and sensitivity. Those levels are 0.6 for sensitivy and four filters of 0.6, 0.7, 0.8 and 0.9 for fuzzy confidence are performed.  
   #'  
   #'  Also, the user can force the algorithm return at least one rule for all target class values, even if not pass the screening function. This 
@@ -688,7 +688,7 @@ Rule.addVariable <- function(rule, dataset){
   #'     \item \code{inputData}  Specify two paths of KEEL files for training and test. In case of specify only the name of the file, the path will be the working directory.
   #'     \item \code{seed}  Sets the seed for the random number generator
   #'     \item \code{nLabels}  Sets the number of fuzzy labels to create when reading the files
-  #'     \item \code{nEval}  Set the maximun number of \strong{evaluations of rules} for stop the genetic process
+  #'     \item \code{nEval}  Set the maximum number of \strong{evaluations of rules} for stop the genetic process
   #'     \item \code{popLength}  Sets number of individuals of the main population
   #'     \item \code{eliteLength}  Sets number of individuals of the elite population. Must be less than \code{popLength}  
   #'     \item \code{crossProb}  Crossover probability of the genetic algorithm. Value in [0,1]
@@ -730,7 +730,7 @@ Rule.addVariable <- function(rule, dataset){
   #' @examples 
   #' FUGEPSD(training = habermanTra,
   #'          test = habermanTst,
-  #'          output = c("parametersFile.txt", "rulesFile.txt", "testQM.txt"),
+  #'          output = c(NA, NA, NA),
   #'          seed = 23783,
   #'          nLabels = 3,
   #'          t_norm = "Minimum/Maximum",
@@ -745,8 +745,9 @@ Rule.addVariable <- function(rule, dataset){
   #'          tournamentSize = 2,
   #'          globalFitnessWeights = c(0.7, 0.1, 0.3, 0.2),
   #'          ALL_CLASS = TRUE)
+  #'          
   #' \dontrun{
-  #' Execution with a parameters file called 'ParamFile.txt' in the working directory:
+  #' # Execution with a parameters file called 'ParamFile.txt' in the working directory:
   #' 
   #' FUGEPSD("ParamFile.txt")
   #' 
@@ -886,7 +887,7 @@ Rule.addVariable <- function(rule, dataset){
     }
     set.seed(parameters$seed)
     
-    cat("\n\nSearching Rules for all classes...\n\n")
+    message("\n\nSearching Rules for all classes...\n\n")
     
     #Execute the genetic algorithm
     pop <- .gaFuGePSD(type = parameters[[18]],
@@ -973,6 +974,7 @@ Rule.addVariable <- function(rule, dataset){
      
      #Change the name of the output file by the following: $fileName$_filtro_AllClass.txt for rules file with filter 'filtro'
      #                                                     $fileName$_filtro_AllClass_QM.txt
+     if(! is.na(parameters$outputData[2])){
      ruleFileName <- paste(substr(parameters$outputData[2], 1, regexpr("\\.[^\\.]*$", parameters$outputData[2]) - 1),
                                 "_f", paste(substr(as.character(minCnf), 1, 1) , substr(as.character(minCnf), 3, 3) , sep = ""), "_", 
                                 AllClass, ".txt", sep = "")
@@ -981,12 +983,12 @@ Rule.addVariable <- function(rule, dataset){
                            "_f", paste(substr(as.character(minCnf), 1, 1) , substr(as.character(minCnf), 3, 3) , sep = ""), "_", 
                            AllClass, "_QM", ".txt", sep = "")
       
-      cat("\n\n---- FILTER: ", minCnf, " ----\n\n", sep = "")
+      message("\n\n---- FILTER: ", minCnf, " ----\n\n", sep = "")
      
       writeRuleFile(new_pop, training, ruleFileName)
-      cat("\n QUALITY MEASURES OF THE RULES GENERATED: \n\n")
+      message("\n QUALITY MEASURES OF THE RULES GENERATED: \n\n")
       writeTestQMFile(new_pop, testQMFileName, test$Ns)
-   
+      }
       #Create the rulesToReturn structure to return the rules
       ##Add values to the rulesToReturn Object
       rulesToReturn <- vector(mode = "list", length = length(new_pop))
@@ -1008,7 +1010,7 @@ Rule.addVariable <- function(rule, dataset){
       count <- count + 1
       }
    
-   cat("\n\nAlgorithm finished. \nExecution time: ", parseTime(as.numeric(Sys.time()), init_time),  "\n\n", sep = "")
+   message("\n\nAlgorithm finished. \nExecution time: ", parseTime(as.numeric(Sys.time()), init_time),  "\n\n", sep = "")
     
    #return
    class(rulesToReturn) <- "SDEFSR_Rules"
@@ -1213,7 +1215,7 @@ writeRuleFile <- function(pop, dataset, fileName){
   
   finalLine <- paste("@Number of rules: ", numRules, "\n@Average number of variables: ", round(sumVars / numRules, 2), "\n\n", RulesLine, sep = "")
   
-  cat(finalLine) #Prints in the console
+  message(finalLine) #Prints in the console
   cat(finalLine, file = fileName) #Prints in the file
   
   invisible()
@@ -1283,7 +1285,7 @@ writeTestQMFile <- function(pop, fileName, numExamples){
        sep = "\n"
   )
   #Print exit
-  cat(Salida) # On console
+  message(Salida) # On console
   cat(Salida, file = fileName) #On file.
   
   invisible()
@@ -1326,7 +1328,9 @@ printFuGePSDParameters <- function(parameters, dataset, inputFromFiles = TRUE){
       "All Class: ", parameters$allClass, "\n",
       "-----------------------------------------------------------\n\n", sep = "")
  
-  cat(line)  #Print in console
-  cat(line, file = parameters$outputData[1])
+  message(line)  #Print in console
+  if(! is.na(parameters$outputData[1])){
+    cat(line, file = parameters$outputData[1])
+  }
   
 }
